package run;
import java.io.File;
import java.io.IOException;
import java.util.Scanner;

import pt.ul.fc.di.nlx.lxServiceClient.LXClient;
import pt.ul.fc.di.nlx.lxServiceClient.exceptions.LXException;

/**
 * <p>This class is a sample that uses <code>LXService</code> through <code>LXClient</code>.</p> 
 *  
 * @author NLX-Natural Language and Speech Group of the University of Lisbon, Department of Informatics
 * @version 1.0 (2008-03-07)
 */
public class TestClient {
	
	/**
	 * <p>Reads the file with the text to be passed to <code>LXClient</code>.</p>
	 * 
	 * @param fileName the name of the file with the text (this file should be encoded in UTF-8).
	 * @return the text contained in the file.
	 */
	private String readFile( String fileName ){
		String text = "";
		try{
			Scanner file = new Scanner( new File( fileName ), "UTF-8" );

			while ( file.hasNext() )
				text += file.nextLine();

			file.close();
		}catch (IOException e) {
			e.printStackTrace();
		}
		
		return text;
	}
	
	/**
	 * <p>Main method.</p>
	 * 
	 * <p>This is an example of use of <code>LXClient</code>.</p>
	 * <p>This method receives two arguments: 
	 * (1) the <code>LXClient</code> username and 
	 * (2) the name of the file containing the text to be
	 * passed to <code>LXClient</code>.</p>
	 * 
	 * <p> First, reads the file with the input text. Then, calls all
	 * <code>LXClient</code> available methods and prints their result.</p>
	 * 
	 * @param args the arguments to be received by the main method. 
	 */
	public static void main(String[] args) {
		
		if ( args.length != 2 )
			System.err.println( "\n---- Command:\njava run.TestClient [username] [path/.../filename]\n" );
		else{
			try{
				// Reading the file given in the command path.
				String inputText = new TestClient().readFile( args[1] );

				// Creating an LXClient object
				LXClient client = new LXClient( args[0] );

				// Calls the chunk method
				String chunkedText = client.chunks( inputText );

				// Prints the String returned by the service
				System.out.println( "Chunked text:\n" + chunkedText );

				// Calls the tokenizer method
				String tokenizedText = client.tokenizes( inputText );

				// Prints the String returned by the service
				System.out.println( "\nTokenized text:\n" + tokenizedText );

				// Calls the posTagger method
				String posTaggedText = client.posTags( inputText );

				// Prints the String returned by the service
				System.out.println( "\nPOS Tagged text:\n" + posTaggedText );
				
			}catch (LXException e) {
				e.printStackTrace();
			}
		}
	}
}
